@@ -7,8 +7,8 @@ idxint p = 0;
 idxint l = 4;
 idxint ncones = 0;
 pfloat c[2] = {-1.000000000000000000e+00, -1.000000000000000000e+00};
-idxint Gjc[3] = {0.0, 3, 6};
-idxint Gir[6] = {0.0, 1, 2, 0.0, 1, 3};
+idxint Gjc[3] = {0, 3, 6};
+idxint Gir[6] = {0, 1, 2, 0, 1, 3};
 pfloat Gpr[6] = {-2.000000000000000000e+00, -1.000000000000000222e+00, -1.000000000000000000e+00, -9.999999999999998890e-01, -3.000000000000000000e+00, -1.000000000000000000e+00};
 pfloat h[4] = {-1.000000000000000000e+00, -1.000000000000000000e+00, 0.0, 0.0};
 idxint *q = NULL;
